@@ -31,7 +31,7 @@
       integer rnk,i,j,l,iter,rango
       integer scaloop,imode
       integer npoints
-      logical stable,discarded
+      logical stable,discarded,ext_num_for_r1
 !---------------------------------------------------------------------
 ! Read number of MC points, the number of propagators and the rank:
 !--------------------------------------------------------------------- 
@@ -54,6 +54,7 @@
       roots     = 50.d0         ! value of sqrt(s)
       rootsvalue= roots
       limitvalue= 1.d-2 
+      ext_num_for_r1=.true.
       imode     = 0
 
 !---------------------------------------------------------------------
@@ -72,7 +73,7 @@
          xm(i) = 1.d0
       enddo
 !---------------------------------------------------------------------
-! To initialize CutTools call ctsinit(limitvalue,scaloop)
+! To initialize CutTools call ctsinit(limitvalue,scaloop,ext_num_for_r1)
 !
 ! INPUT:
 !
@@ -85,9 +86,13 @@
 !                               scaloop= 1 -> looptools (not implemented) 
 !                               scaloop= 2 -> avh (complex masses)   
 !                               scaloop= 3 -> qcdloop.  
+!
+!      logical ext_num_for_r1 -> numfunc or numfuncrec is used in the
+!                                computation of R1 if put to .true. 
+!                                or .false
 ! OUTPUT: none
 !---------------------------------------------------------------------
-      call ctsinit(limitvalue,scaloop)
+      call ctsinit(limitvalue,scaloop,ext_num_for_r1)
       do iter= 1,npoints   ! do-loop over events 
         if     (number_propagators.ge.4) then
            call rambo(0,number_propagators-2,roots,xm,p)
